
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/List/Objects/WithUtils.pm',
    'lib/List/Objects/WithUtils/Array.pm',
    'lib/List/Objects/WithUtils/Array/Immutable.pm',
    'lib/List/Objects/WithUtils/Array/Immutable/Typed.pm',
    'lib/List/Objects/WithUtils/Array/Junction.pm',
    'lib/List/Objects/WithUtils/Array/Typed.pm',
    'lib/List/Objects/WithUtils/Autobox.pm',
    'lib/List/Objects/WithUtils/Hash.pm',
    'lib/List/Objects/WithUtils/Hash/Immutable.pm',
    'lib/List/Objects/WithUtils/Hash/Immutable/Typed.pm',
    'lib/List/Objects/WithUtils/Hash/Inflated.pm',
    'lib/List/Objects/WithUtils/Hash/Inflated/RW.pm',
    'lib/List/Objects/WithUtils/Hash/Typed.pm',
    'lib/List/Objects/WithUtils/Role/Array.pm',
    'lib/List/Objects/WithUtils/Role/Array/Immutable.pm',
    'lib/List/Objects/WithUtils/Role/Array/TiedRO.pm',
    'lib/List/Objects/WithUtils/Role/Array/Typed.pm',
    'lib/List/Objects/WithUtils/Role/Array/WithJunctions.pm',
    'lib/List/Objects/WithUtils/Role/Hash.pm',
    'lib/List/Objects/WithUtils/Role/Hash/Immutable.pm',
    'lib/List/Objects/WithUtils/Role/Hash/TiedRO.pm',
    'lib/List/Objects/WithUtils/Role/Hash/Typed.pm',
    'lib/Lowu.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/00_load/all.t',
    't/00_load/all_typetinyish.t',
    't/00_load/autobox.t',
    't/00_load/autobox_subclass.t',
    't/00_load/badopts.t',
    't/00_load/bare.t',
    't/00_load/functions.t',
    't/00_load/hashopts.t',
    't/00_load/lowu.t',
    't/00_load/selective.t',
    't/00_load/targeted.t',
    't/01_array/all.t',
    't/01_array/bisect.t',
    't/01_array/clear.t',
    't/01_array/copy.t',
    't/01_array/count.t',
    't/01_array/defined.t',
    't/01_array/delete.t',
    't/01_array/delete_when.t',
    't/01_array/diff.t',
    't/01_array/end.t',
    't/01_array/exists.t',
    't/01_array/first_index.t',
    't/01_array/first_where.t',
    't/01_array/flatten.t',
    't/01_array/flatten_all.t',
    't/01_array/folds.t',
    't/01_array/get.t',
    't/01_array/get_or_else.t',
    't/01_array/grep.t',
    't/01_array/has_any.t',
    't/01_array/head.t',
    't/01_array/indexes.t',
    't/01_array/inflate.t',
    't/01_array/insert.t',
    't/01_array/intersection.t',
    't/01_array/is_empty.t',
    't/01_array/items_after.t',
    't/01_array/items_after_incl.t',
    't/01_array/items_before.t',
    't/01_array/items_before_incl.t',
    't/01_array/join.t',
    't/01_array/kv.t',
    't/01_array/last_index.t',
    't/01_array/last_where.t',
    't/01_array/map.t',
    't/01_array/mapval.t',
    't/01_array/mesh.t',
    't/01_array/natatime.t',
    't/01_array/nsect.t',
    't/01_array/nsort_by.t',
    't/01_array/part.t',
    't/01_array/part_to_hash.t',
    't/01_array/pick.t',
    't/01_array/pop.t',
    't/01_array/push.t',
    't/01_array/random.t',
    't/01_array/repeated.t',
    't/01_array/reverse.t',
    't/01_array/roll.t',
    't/01_array/rotate.t',
    't/01_array/rotate_in_place.t',
    't/01_array/rotator.t',
    't/01_array/set.t',
    't/01_array/shift.t',
    't/01_array/shuffle.t',
    't/01_array/sliced.t',
    't/01_array/sort.t',
    't/01_array/sort_by.t',
    't/01_array/splice.t',
    't/01_array/ssect.t',
    't/01_array/subclassed.t',
    't/01_array/tail.t',
    't/01_array/tuples.t',
    't/01_array/type.t',
    't/01_array/unbless.t',
    't/01_array/uniq.t',
    't/01_array/uniq_by.t',
    't/01_array/unshift.t',
    't/01_array/utilsby_no_xs.t',
    't/01_array/visit.t',
    't/02_hash/array_type.t',
    't/02_hash/clear.t',
    't/02_hash/copy.t',
    't/02_hash/defined.t',
    't/02_hash/delete.t',
    't/02_hash/diff.t',
    't/02_hash/exists.t',
    't/02_hash/export.t',
    't/02_hash/get.t',
    't/02_hash/get_or_else.t',
    't/02_hash/get_path.t',
    't/02_hash/inflate.t',
    't/02_hash/intersection.t',
    't/02_hash/inverted.t',
    't/02_hash/is_empty.t',
    't/02_hash/iter.t',
    't/02_hash/keys.t',
    't/02_hash/kv.t',
    't/02_hash/kv_grep.t',
    't/02_hash/kv_map.t',
    't/02_hash/kv_sort.t',
    't/02_hash/maybe_set.t',
    't/02_hash/set.t',
    't/02_hash/sliced.t',
    't/02_hash/subclassed.t',
    't/02_hash/unbless.t',
    't/02_hash/values.t',
    't/03_junctions/all.t',
    't/03_junctions/any.t',
    't/03_junctions/subclasses.t',
    't/04_immutable/immarray.t',
    't/04_immutable/immhash.t',
    't/05_typed/array_of.t',
    't/05_typed/hash_of.t',
    't/05_typed/tuples.t',
    't/05_typed/validated.t',
    't/06_immutable_typed/immarray_of.t',
    't/06_immutable_typed/immhash_of.t',
    't/07_json/json.t',
    't/08_zpl/zpl.t',
    't/09_autobox_array/all.t',
    't/09_autobox_array/bisect.t',
    't/09_autobox_array/clear.t',
    't/09_autobox_array/copy.t',
    't/09_autobox_array/count.t',
    't/09_autobox_array/defined.t',
    't/09_autobox_array/delete.t',
    't/09_autobox_array/delete_when.t',
    't/09_autobox_array/diff.t',
    't/09_autobox_array/end.t',
    't/09_autobox_array/exists.t',
    't/09_autobox_array/first_index.t',
    't/09_autobox_array/first_where.t',
    't/09_autobox_array/flatten.t',
    't/09_autobox_array/flatten_all.t',
    't/09_autobox_array/folds.t',
    't/09_autobox_array/get.t',
    't/09_autobox_array/get_or_else.t',
    't/09_autobox_array/grep.t',
    't/09_autobox_array/has_any.t',
    't/09_autobox_array/head.t',
    't/09_autobox_array/indexes.t',
    't/09_autobox_array/inflate.t',
    't/09_autobox_array/insert.t',
    't/09_autobox_array/intersection.t',
    't/09_autobox_array/items_after.t',
    't/09_autobox_array/items_after_incl.t',
    't/09_autobox_array/items_before.t',
    't/09_autobox_array/items_before_incl.t',
    't/09_autobox_array/join.t',
    't/09_autobox_array/kv.t',
    't/09_autobox_array/last_index.t',
    't/09_autobox_array/last_where.t',
    't/09_autobox_array/map.t',
    't/09_autobox_array/mapval.t',
    't/09_autobox_array/mesh.t',
    't/09_autobox_array/natatime.t',
    't/09_autobox_array/nsect.t',
    't/09_autobox_array/nsort_by.t',
    't/09_autobox_array/part.t',
    't/09_autobox_array/part_to_hash.t',
    't/09_autobox_array/pop.t',
    't/09_autobox_array/push.t',
    't/09_autobox_array/random.t',
    't/09_autobox_array/reverse.t',
    't/09_autobox_array/rotate.t',
    't/09_autobox_array/rotate_in_place.t',
    't/09_autobox_array/rotator.t',
    't/09_autobox_array/set.t',
    't/09_autobox_array/shift.t',
    't/09_autobox_array/shuffle.t',
    't/09_autobox_array/sliced.t',
    't/09_autobox_array/sort.t',
    't/09_autobox_array/sort_by.t',
    't/09_autobox_array/splice.t',
    't/09_autobox_array/ssect.t',
    't/09_autobox_array/tail.t',
    't/09_autobox_array/tuples.t',
    't/09_autobox_array/uniq.t',
    't/09_autobox_array/uniq_by.t',
    't/09_autobox_array/unshift.t',
    't/09_autobox_array/utilsby_no_xs.t',
    't/09_autobox_array/visit.t',
    't/09_autobox_hash/array_type.t',
    't/09_autobox_hash/clear.t',
    't/09_autobox_hash/copy.t',
    't/09_autobox_hash/defined.t',
    't/09_autobox_hash/delete.t',
    't/09_autobox_hash/diff.t',
    't/09_autobox_hash/exists.t',
    't/09_autobox_hash/get.t',
    't/09_autobox_hash/get_or_else.t',
    't/09_autobox_hash/get_path.t',
    't/09_autobox_hash/inflate.t',
    't/09_autobox_hash/intersection.t',
    't/09_autobox_hash/inverted.t',
    't/09_autobox_hash/iter.t',
    't/09_autobox_hash/keys.t',
    't/09_autobox_hash/kv.t',
    't/09_autobox_hash/kv_grep.t',
    't/09_autobox_hash/kv_map.t',
    't/09_autobox_hash/kv_sort.t',
    't/09_autobox_hash/maybe_set.t',
    't/09_autobox_hash/set.t',
    't/09_autobox_hash/sliced.t',
    't/09_autobox_hash/values.t',
    't/author-no-tabs.t',
    't/author-pod-coverage.t',
    't/author-pod-syntax.t',
    't/release-cpan-changes.t',
    't/release-dist-manifest.t',
    't/release-pod-linkcheck.t',
    't/release-portability.t',
    't/release-synopsis.t'
);

notabs_ok($_) foreach @files;
done_testing;
